@@ -49,6 +49,11 @@ class Builder(_BaseRepositoryObject):
     def __ne__(self, other):
         return not self == other
 
+    def sync(self):
+        """Synchronize local and remote repositories.
+        """
+        self.repo.sync()
+
     def run(self):
         """Perform one build iteration.
         """
@@ -62,7 +67,7 @@ class Builder(_BaseRepositoryObject):
                     continue
 
                 # Check out build request's changeset
-                logging.info("found build request: {0}".format(request))
+                logging.info("found build request: {0} in {1}".format(request, request.repo))
                 self.count += 1
                 with self.repo.checkout(tempfile.mkdtemp(), rev=request.changeset.rev) as work:
 
@@ -79,23 +84,28 @@ class Builder(_BaseRepositoryObject):
                     self.create_virtualenv()
 
                     # Build loop
-                    while True:
+                    try:
+                        while True:
 
-                        # Enter the next build state
-                        request.update(self.config.next(request.status))
+                            # Enter the next build state
+                            request.update(self.config.next(request.status))
 
-                        # Run the command for the current state
-                        path, command = self.config.get_build(request.status)
-                        work.chdir()
-                        success = self.call(path, command)
+                            # Run the command for the current state
+                            path, command = self.config.get_build(request.status)
+                            work.chdir()
+                            success = self.call(path, command)
 
-                        # Process the command results
-                        if success:
-                            request.update(self.config.exit(request.status))
-                        else:
-                            request.update(self.config.fail(request.status))
-                        if request.status in self.config.ends:
-                            break
+                            # Process the command results
+                            if success:
+                                request.update(self.config.exit(request.status))
+                            else:
+                                request.update(self.config.fail(request.status))
+                            if request.status in self.config.ends:
+                                break
+
+                    except ValueError:
+                        logging.critical("deleting build request due to invalid configuration: {0}".format(request))
+                        request.delete()
 
                 # Build completed
                 self.stats[request.status] += 1
@@ -181,6 +191,7 @@ def run(config, daemon=False, test=False):
 
     while True:
         for builder in builders:
+            builder.sync()
             if isinstance(test, basestring):
                 logging.info("testing [{s}] of {b}...".format(b=builder, s=test))
                 builder.test(single=test)
@@ -188,8 +199,9 @@ def run(config, daemon=False, test=False):
                 logging.info("testing {b}...".format(b=builder))
                 builder.test()
             else:
-                logging.info("running {b}...".format(b=builder))
+                logging.log(logging.DEBUG if daemon else logging.INFO, "running {b}...".format(b=builder))
                 builder.run()
+            builder.sync()
         if not daemon or test:
             break
 
