@@ -151,13 +151,6 @@ class Repository(_Base):
             else:
                 raise VeracityException("repository does not exist: {0}".format(name))
 
-    def __del__(self):
-        if settings.AUTO_PUSH:
-            try:
-                self.push(_auto=True)
-            except VeracityException:
-                pass
-
     def __repr__(self):
         return self._repr(self.name)
 
@@ -219,7 +212,7 @@ class Repository(_Base):
                 vv.run('pull', dest=self.name)
             except VeracityException:
                 logging.warning("no remote repository for pull")
-            else:  # pragma: no cover - test repositories are explicitly cloned
+            else:
                 self._pull_time = time.time()
 
     def push(self, remote=None, _auto=False):
@@ -242,9 +235,17 @@ class Repository(_Base):
                 vv.run('push', src=self.name)
             except VeracityException:
                 logging.warning("no remote repository for push")
-            else:  # pragma: no cover - test repositories are explicitly cloned
+            else:
                 self._push_time = time.time()
 
+    def sync(self):
+        """If enabled, perform an automatic pull an push.
+        """
+        if self._auto_pull:
+            self.pull()
+        if self._auto_push:
+            self.push()
+
     @property
     @auto_pull
     def branches(self):
