@@ -74,6 +74,10 @@ class TestRepository(unittest.TestCase):
         """Verify attribute access behaves normally for repositories."""
         self.assertRaises(AttributeError, getattr, TEST_REPO, '_invalid')
 
+    def test_sync(self):
+        """Verify a non-cloned repository can handle pull/push."""
+        TEST_REPO.sync()
+
 
 @unittest.skipUnless(TEST_REPO, REASON)  # pylint: disable=R0904
 class TestWorkingCopy(unittest.TestCase):
@@ -279,12 +283,14 @@ class TestItem(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         if TEST_REPO:
-            cls.wc = WorkingCopy(tempfile.mkdtemp(), repo=TEST_REPO)
+            cls.repo = Repository(TEMP_REPO_NAME, remote=TEST_REPO, autosync=False)
+            cls.wc = WorkingCopy(tempfile.mkdtemp(), repo=cls.repo)
 
     @classmethod
     def tearDownClass(cls):
         if TEST_REPO:
             cls.wc.delete()
+            cls.repo.delete()
 
     def test_init_existing_ws_instance(self):
         """Verify an item can be created from an existing WorkingCopy instance."""
