@@ -30,8 +30,10 @@ class TestPoller(unittest.TestCase):  # pylint: disable=R0904
 
     def test_build_name(self):
         """Verify the correct build name is returned."""
-        name = Poller.name(1, 1000042, 'S', 'E', Changeset('abcde12345xxx'), Branch('dev', rev='abcde12345xxx'))
-        self.assertEqual("01/12 08:47:22 abcde12345", name)
+        name = Poller.name(1, 1000042, 'S', 'E', Changeset('abcde12345xxx'), Branch('dev', rev='abcde12345xxx')).split()
+        self.assertIn("/", name[0])
+        self.assertEqual(2, name[1].count(':'))
+        self.assertEqual("abcde12345", name[2])
 
 
 @unittest.skipUnless(TEST_REPO, REASON)  # pylint: disable=R0904
@@ -48,9 +50,11 @@ class TestRun(unittest.TestCase):  # pylint: disable=R0904
         if TEST_REPO:
             cls.repo.delete()
 
+    def setUp(self):
+        del self.repo.builds
+
     def test_run_valid(self):
         """Verify a poller can be run."""
-        del self.repo.builds
         self.assertTrue(run(Config(path=os.path.join(FILES, 'poller.cfg'), repos=[self.repo.name], series=['C'])))
         self.assertEqual(3, len(list(self.repo.builds)))
         self.assertTrue(run(Config(path=os.path.join(FILES, 'poller.cfg'), repos=[self.repo.name], series=['C'])))
@@ -58,7 +62,6 @@ class TestRun(unittest.TestCase):  # pylint: disable=R0904
 
     def test_run_valid_with_rebuild(self):
         """Verify a poller can be run for a series that rebuilds."""
-        del self.repo.builds
         self.assertTrue(run(Config(path=os.path.join(FILES, 'poller.cfg'), repos=[self.repo.name], series=['N'])))
         self.assertEqual(3, len(list(self.repo.builds)))
         self.assertTrue(run(Config(path=os.path.join(FILES, 'poller.cfg'), repos=[self.repo.name], series=['N'])))
